sqlobject.tests.test_schema module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_schema module

class `sqlobject.tests.test_schema.` `SOTestSchema`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `foo`
  `j` = so_test_schema
  `q` = so_test_schema
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_schema.SOTestSchema`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_schema'

`sqlobject.tests.test_schema.` `test_connection_schema`()